pytilities.descriptors — Pytilities 1.2.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities 1.2.0 documentation »
- API documentation »
- pytilities »

# pytilities.descriptors

Contents

- AttributeDescriptor
- BoundDescriptor
- DereferencedBoundDescriptor
- DereferencedDescriptor
- RestrictedDescriptor

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities 1.2.0 documentation »
- API documentation »
- pytilities »